@@ -57,19 +57,22 @@ class Manager:
         NOTE: works only when the security is token-based or there is also no password
         """
         connection_file = os.path.basename(ipykernel.get_connection_file())
-        kernel_id = connection_file.split("-", 1)[1].split(".")[0]
-        for srv in notebookapp.list_running_servers():
-            try:
-                base_url = f"{self.__public_url}/user/{self.__jup_user}/api/sessions"
-                req = urllib.request.urlopen(f"{base_url}?token={self.__jup_token}")
-                sessions = json.load(req)
-                for sess in sessions:
-                    if sess["kernel"]["id"] == kernel_id:
-                        return os.path.join(
-                            srv["notebook_dir"], sess["notebook"]["path"]
-                        )
-            except urllib.error.HTTPError:
-                pass
+        try:
+            kernel_id = connection_file.split("-", 1)[1].split(".")[0]
+            for srv in notebookapp.list_running_servers():
+                try:
+                    base_url = f"{self.__public_url}/user/{self.__jup_user}/api/sessions"
+                    req = urllib.request.urlopen(f"{base_url}?token={self.__jup_token}")
+                    sessions = json.load(req)
+                    for sess in sessions:
+                        if sess["kernel"]["id"] == kernel_id:
+                            return os.path.join(
+                                srv["notebook_dir"], sess["notebook"]["path"]
+                            )
+                except urllib.error.HTTPError:
+                    pass
+        except IndexError:
+            pass
         return None
 
     def get_path(self, path):
